# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: account_permissions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61\x63\x63ount_permissions.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"\x8b\x01\n\x1c\x41\x63\x63ountPermissionListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\x82\x02\n\x1d\x41\x63\x63ountPermissionListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x36\n\x0bpermissions\x18\x02 \x03(\x0b\x32\x15.v1.AccountPermissionB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xfd\x01\n\x11\x41\x63\x63ountPermission\x12\x1e\n\naccount_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ngranted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1e\n\npermission\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x19\n\x05scope\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\tscoped_id\x18\x05 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xd6\x01\n\x12\x41\x63\x63ountPermissions\x12{\n\x04List\x12 .v1.AccountPermissionListRequest\x1a!.v1.AccountPermissionListResponse\".\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1c\xaa\xf3\xb3\x07\x17/v1/account-permissions\x1a\x43\xca\xf9\xb3\x07\x16\xc2\xf9\xb3\x07\x11\x41\x63\x63ountPermission\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x96\x01\n\x19\x63om.strongdm.api.plumbingB\x1a\x41\x63\x63ountPermissionsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ACCOUNTPERMISSIONLISTREQUEST = DESCRIPTOR.message_types_by_name['AccountPermissionListRequest']
_ACCOUNTPERMISSIONLISTRESPONSE = DESCRIPTOR.message_types_by_name['AccountPermissionListResponse']
_ACCOUNTPERMISSION = DESCRIPTOR.message_types_by_name['AccountPermission']
AccountPermissionListRequest = _reflection.GeneratedProtocolMessageType('AccountPermissionListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPERMISSIONLISTREQUEST,
  '__module__' : 'account_permissions_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountPermissionListRequest)
  })
_sym_db.RegisterMessage(AccountPermissionListRequest)

AccountPermissionListResponse = _reflection.GeneratedProtocolMessageType('AccountPermissionListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPERMISSIONLISTRESPONSE,
  '__module__' : 'account_permissions_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountPermissionListResponse)
  })
_sym_db.RegisterMessage(AccountPermissionListResponse)

AccountPermission = _reflection.GeneratedProtocolMessageType('AccountPermission', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTPERMISSION,
  '__module__' : 'account_permissions_pb2'
  # @@protoc_insertion_point(class_scope:v1.AccountPermission)
  })
_sym_db.RegisterMessage(AccountPermission)

_ACCOUNTPERMISSIONS = DESCRIPTOR.services_by_name['AccountPermissions']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\032AccountPermissionsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ACCOUNTPERMISSIONLISTREQUEST.fields_by_name['filter']._options = None
  _ACCOUNTPERMISSIONLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTPERMISSIONLISTREQUEST._options = None
  _ACCOUNTPERMISSIONLISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCOUNTPERMISSIONLISTRESPONSE.fields_by_name['permissions']._options = None
  _ACCOUNTPERMISSIONLISTRESPONSE.fields_by_name['permissions']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ACCOUNTPERMISSIONLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ACCOUNTPERMISSIONLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ACCOUNTPERMISSIONLISTRESPONSE._options = None
  _ACCOUNTPERMISSIONLISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCOUNTPERMISSION.fields_by_name['account_id']._options = None
  _ACCOUNTPERMISSION.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTPERMISSION.fields_by_name['granted_at']._options = None
  _ACCOUNTPERMISSION.fields_by_name['granted_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTPERMISSION.fields_by_name['permission']._options = None
  _ACCOUNTPERMISSION.fields_by_name['permission']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTPERMISSION.fields_by_name['scope']._options = None
  _ACCOUNTPERMISSION.fields_by_name['scope']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTPERMISSION.fields_by_name['scoped_id']._options = None
  _ACCOUNTPERMISSION.fields_by_name['scoped_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ACCOUNTPERMISSION._options = None
  _ACCOUNTPERMISSION._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ACCOUNTPERMISSIONS._options = None
  _ACCOUNTPERMISSIONS._serialized_options = b'\312\371\263\007\026\302\371\263\007\021AccountPermission\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _ACCOUNTPERMISSIONS.methods_by_name['List']._options = None
  _ACCOUNTPERMISSIONS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\034\252\363\263\007\027/v1/account-permissions'
  _ACCOUNTPERMISSIONLISTREQUEST._serialized_start=94
  _ACCOUNTPERMISSIONLISTREQUEST._serialized_end=233
  _ACCOUNTPERMISSIONLISTRESPONSE._serialized_start=236
  _ACCOUNTPERMISSIONLISTRESPONSE._serialized_end=494
  _ACCOUNTPERMISSION._serialized_start=497
  _ACCOUNTPERMISSION._serialized_end=750
  _ACCOUNTPERMISSIONS._serialized_start=753
  _ACCOUNTPERMISSIONS._serialized_end=967
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import secret_store_healths_pb2 as secret__store__healths__pb2


class SecretStoreHealthsStub(object):
    """SecretStoreHealths exposes health states for secret stores.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.List = channel.unary_unary(
                '/v1.SecretStoreHealths/List',
                request_serializer=secret__store__healths__pb2.SecretStoreHealthListRequest.SerializeToString,
                response_deserializer=secret__store__healths__pb2.SecretStoreHealthListResponse.FromString,
                )
        self.Check = channel.unary_unary(
                '/v1.SecretStoreHealths/Check',
                request_serializer=secret__store__healths__pb2.SecretStoreHealthCheckRequest.SerializeToString,
                response_deserializer=secret__store__healths__pb2.SecretStoreHealthCheckResponse.FromString,
                )
        self.Healthcheck = channel.unary_unary(
                '/v1.SecretStoreHealths/Healthcheck',
                request_serializer=secret__store__healths__pb2.SecretStoreHealthcheckRequest.SerializeToString,
                response_deserializer=secret__store__healths__pb2.SecretStoreHealthcheckResponse.FromString,
                )


class SecretStoreHealthsServicer(object):
    """SecretStoreHealths exposes health states for secret stores.
    """

    def List(self, request, context):
        """List reports the health status of node to secret store pairs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Check(self, request, context):
        """Check pushes a healthcheck request for a secret store
        Deprecated: use Healthcheck instead
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Healthcheck(self, request, context):
        """Healthcheck triggers a remote healthcheck request for a secret store. It may take minutes
        to propagate across a large network of Nodes. The call will return immediately, and the
        updated health of the Secret Store can be retrieved via List.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SecretStoreHealthsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=secret__store__healths__pb2.SecretStoreHealthListRequest.FromString,
                    response_serializer=secret__store__healths__pb2.SecretStoreHealthListResponse.SerializeToString,
            ),
            'Check': grpc.unary_unary_rpc_method_handler(
                    servicer.Check,
                    request_deserializer=secret__store__healths__pb2.SecretStoreHealthCheckRequest.FromString,
                    response_serializer=secret__store__healths__pb2.SecretStoreHealthCheckResponse.SerializeToString,
            ),
            'Healthcheck': grpc.unary_unary_rpc_method_handler(
                    servicer.Healthcheck,
                    request_deserializer=secret__store__healths__pb2.SecretStoreHealthcheckRequest.FromString,
                    response_serializer=secret__store__healths__pb2.SecretStoreHealthcheckResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.SecretStoreHealths', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SecretStoreHealths(object):
    """SecretStoreHealths exposes health states for secret stores.
    """

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretStoreHealths/List',
            secret__store__healths__pb2.SecretStoreHealthListRequest.SerializeToString,
            secret__store__healths__pb2.SecretStoreHealthListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Check(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretStoreHealths/Check',
            secret__store__healths__pb2.SecretStoreHealthCheckRequest.SerializeToString,
            secret__store__healths__pb2.SecretStoreHealthCheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Healthcheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.SecretStoreHealths/Healthcheck',
            secret__store__healths__pb2.SecretStoreHealthcheckRequest.SerializeToString,
            secret__store__healths__pb2.SecretStoreHealthcheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import remote_identities_pb2 as remote__identities__pb2


class RemoteIdentitiesStub(object):
    """RemoteIdentities assign a resource directly to an account, giving the account the permission to connect to that resource.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/v1.RemoteIdentities/Create',
                request_serializer=remote__identities__pb2.RemoteIdentityCreateRequest.SerializeToString,
                response_deserializer=remote__identities__pb2.RemoteIdentityCreateResponse.FromString,
                )
        self.Get = channel.unary_unary(
                '/v1.RemoteIdentities/Get',
                request_serializer=remote__identities__pb2.RemoteIdentityGetRequest.SerializeToString,
                response_deserializer=remote__identities__pb2.RemoteIdentityGetResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/v1.RemoteIdentities/Update',
                request_serializer=remote__identities__pb2.RemoteIdentityUpdateRequest.SerializeToString,
                response_deserializer=remote__identities__pb2.RemoteIdentityUpdateResponse.FromString,
                )
        self.Delete = channel.unary_unary(
                '/v1.RemoteIdentities/Delete',
                request_serializer=remote__identities__pb2.RemoteIdentityDeleteRequest.SerializeToString,
                response_deserializer=remote__identities__pb2.RemoteIdentityDeleteResponse.FromString,
                )
        self.List = channel.unary_unary(
                '/v1.RemoteIdentities/List',
                request_serializer=remote__identities__pb2.RemoteIdentityListRequest.SerializeToString,
                response_deserializer=remote__identities__pb2.RemoteIdentityListResponse.FromString,
                )


class RemoteIdentitiesServicer(object):
    """RemoteIdentities assign a resource directly to an account, giving the account the permission to connect to that resource.
    """

    def Create(self, request, context):
        """Create registers a new RemoteIdentity.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Get reads one RemoteIdentity by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Update replaces all the fields of a RemoteIdentity by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Delete removes a RemoteIdentity by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """List gets a list of RemoteIdentities matching a given set of criteria.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RemoteIdentitiesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=remote__identities__pb2.RemoteIdentityCreateRequest.FromString,
                    response_serializer=remote__identities__pb2.RemoteIdentityCreateResponse.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=remote__identities__pb2.RemoteIdentityGetRequest.FromString,
                    response_serializer=remote__identities__pb2.RemoteIdentityGetResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=remote__identities__pb2.RemoteIdentityUpdateRequest.FromString,
                    response_serializer=remote__identities__pb2.RemoteIdentityUpdateResponse.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=remote__identities__pb2.RemoteIdentityDeleteRequest.FromString,
                    response_serializer=remote__identities__pb2.RemoteIdentityDeleteResponse.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=remote__identities__pb2.RemoteIdentityListRequest.FromString,
                    response_serializer=remote__identities__pb2.RemoteIdentityListResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'v1.RemoteIdentities', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RemoteIdentities(object):
    """RemoteIdentities assign a resource directly to an account, giving the account the permission to connect to that resource.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.RemoteIdentities/Create',
            remote__identities__pb2.RemoteIdentityCreateRequest.SerializeToString,
            remote__identities__pb2.RemoteIdentityCreateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.RemoteIdentities/Get',
            remote__identities__pb2.RemoteIdentityGetRequest.SerializeToString,
            remote__identities__pb2.RemoteIdentityGetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.RemoteIdentities/Update',
            remote__identities__pb2.RemoteIdentityUpdateRequest.SerializeToString,
            remote__identities__pb2.RemoteIdentityUpdateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.RemoteIdentities/Delete',
            remote__identities__pb2.RemoteIdentityDeleteRequest.SerializeToString,
            remote__identities__pb2.RemoteIdentityDeleteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/v1.RemoteIdentities/List',
            remote__identities__pb2.RemoteIdentityListRequest.SerializeToString,
            remote__identities__pb2.RemoteIdentityListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
